"""Comparison: averaging of point estimates vs. proposed KL-optimal combination"""

import numpy as np
from scipy.stats import norm
import matplotlib.pylab as plt

sigmas2 = np.array([1., 100.])
mus = np.array([-5., 0.])
weights = 1./mus.size 

sigma2_ci = 1./(weights/sigmas2).sum()
mu_ci = sigma2_ci * (weights/sigmas2 * mus).sum()
mu_nonci = (weights * mus).sum()

print("CI Sigma2: ", sigma2_ci)
print("CI mu: ", mu_ci)
print("NONCI mu: ", mu_nonci)

x = np.linspace(-9, 11, 100)
m = ['o', '']
plt.figure(1, figsize=(6, 3))
for i in range(mus.size):
    plt.plot(x, norm.pdf(x, mus[i], np.sqrt(sigmas2[i])), 'k', marker=m[i], 
             markevery=5, markersize=4, label='Node '+str(i+1) + ' before combination')
    
plt.plot(x, norm.pdf(x, mu_ci, np.sqrt(sigma2_ci)), '--k', label='Nodes 1,2: proposed comb.')
plt.plot(x, norm.pdf(x, mu_nonci, np.sqrt(sigmas2[0])), ':k', label='Node 1: diffKF', marker=m[0],
         markevery=5, markersize=4)
plt.plot(x, norm.pdf(x, mu_nonci, np.sqrt(sigmas2[1])), ':k', label='Node 2: diffKF')
plt.xlim((-9, 11))

plt.legend(fontsize=11)
plt.grid(None)
plt.savefig('proposed_vs_diffKF.pdf', bbox_inches='tight')