import numpy as np
from scipy.stats.distributions import norm

class Nscalar():
    """Simple estimation of scalar normal model"""
    def __init__(self, xi, nu):
        self.xi = xi                      # Hyperparameter xi
        self.nu = float(nu)               # Hyperparameter nu
        self.mean_log = []                # log of mean values
        self.var_log = []                 # log of variances

    def update(self, y, sigma2):
        """Bayesian update"""
        if np.isscalar(y):
            T = np.array([y/sigma2, .5/sigma2])
        else:
            T = np.array([np.sum(y/sigma2), np.sum(1./(2.*sigma2))])
#            print('y: ', y)
#            print('s2: ', sigma2)
#            print(T)
        self.xi += T.reshape(2,1)
        self.nu += y.size

    def log(self):
        """Logging"""
        self.mean_log.append(self.mean)
        self.var_log.append(self.var)

    @property
    def mean(self):
        """Mean value"""
        return self.xi[0] * self.var

    @property
    def var(self):
        """Variance"""
        return 1./(2. * self.xi[1])

    def predictive_logpdf(self, y, sigma2):
        pass


#%%
if __name__ == '__main__':
    mean0 = 0.
    var0 = 10000.
    xi0 = np.array([mean0/var0, 1./(2. * var0)]).reshape(2,1)
    nu0 = 2.
    
    y_var = 1.
    y_mean = 13.
    ndat = 100
    y = np.random.normal(y_mean, np.sqrt(y_var), size=ndat)
    
    prior = Nscalar(xi0.copy(), nu0)
    
    prior.update(y, np.ones(ndat)*y_var) 
    
#%%    
    for yt in y:
        prior.update(yt, y_var)
        prior.log()
    
    #%%
    import matplotlib.pylab as plt
    mean_log = np.array(prior.mean_log)
    var_log = np.array(prior.var_log)
    plt.plot(prior.mean_log, 'b')
    plt.hold()
    plt.plot(prior.mean_log - 3.*np.sqrt(var_log), 'r')
    plt.plot(prior.mean_log + 3.*np.sqrt(var_log), 'r')