from os import listdir
import numpy as np
import matplotlib.pylab as plt

modes = ['atc', 'a', 'c', 'nocoop']
netmsd = {}

for mode in modes:
    netmsd[mode] = []
    files = listdir(mode)
    files = [f for f in files if f.endswith('.npz')]
    for f in files:
        rec = np.load(mode + '/' + f)        
        netmsd[mode].append(rec['netmsd'])
    netmsd[mode] = np.array(netmsd[mode])

#%% Plotting
markers = ('', '', '', '')
lines = ('-', '-.', '--', ':')
plt.figure(1, figsize=(8, 4.5))
plt.hold(True)
for m, mode in enumerate(modes):
    plt.plot(np.log10(netmsd[mode].mean(axis=0)),
                      lines[m],
                      marker=markers[m], 
                      color='black',
                      lw=1.6)
plt.legend([m.upper() for m in modes], ncol=4)
plt.ylabel('log MSD')
plt.xlabel('t')
#plt.savefig('figs/netmsd.pdf', bbox_inches='tight')