import numpy as np
from scipy.special import expit
#import matplotlib.pylab as plt
import networkx as nx

import sys
sys.path.append('../lib')

from diffest import *
from logreg import *

nnodes = 10
ndat = 500
beta = np.random.uniform(low=-2., high=2., size=4)

#%% Data
X = np.random.uniform(low=-1., size=(ndat, nnodes, beta.shape[0]-1))
X = np.concatenate((np.ones((ndat, nnodes, 1)), X), axis=2)
Xbeta_clear = X.dot(beta)
Xbeta = Xbeta_clear.copy()
p = expit(Xbeta)
y = np.random.binomial(n=1, p=p)

#%% Prior
mean = np.zeros(beta.size)
Sigma = np.eye(beta.size) * 100.
prior = LogReg(mean=mean, Sigma=Sigma)

#%% Network
G = nx.gnp_random_graph(nnodes, 0.25, seed=12345)
adjacency_matrix = nx.adjacency_matrix(G).toarray() + np.eye(nnodes)
#adjacency_matrix = np.eye(nnodes)
net = Network(adjacency_matrix, prior)

#%% Estimation run
for yst, xst in zip(y, X):
    if net.t % 20 == 0:
        print(net.t, ' ', end='', flush=True)
    net.set_obs(yst, xst)
#    net.exchange_obs()
    if net.t > 5:
        net.weights_update()
    net.adapt()
    net.exchange_posteriors()
    net.combine()
    net.log()
    
#%% MSDs
netmsd, nodesmsds = net.msd_nodes('mean_log', beta)
print('\nNET MSD: ', netmsd[-1])
    
#%% Brier
brier_score_log = [node.prior.brier_score_log for node in net.nodes]
brier_score_log = np.array(brier_score_log)
print('Brier: {0:.3f}'.format(brier_score_log[:,-1].mean()))

#%% Saving
fn = 'c/' + str(np.random.randint(100000, 999999)) + '.npz'
np.savez(fn, netmsd=netmsd, 
         nodesmsds=nodesmsds, 
         brier_score_log=brier_score_log)

#%% Plotting
#node_plot = 8
#plt.figure(1)
#plt.clf()
#plt.subplot(321)
#nx.draw_networkx(G)
#plt.subplot(322)
#plt.plot(net.nodes[node_plot].prior.mean_log)
#[plt.axhline(i) for i in beta]
#plt.ylim((-2, 5.))
#plt.subplot(323)
#plt.plot(net.nodes[0].prior.mean_log)
#[plt.axhline(i) for i in beta]
#plt.ylim((-2, 5.))
#plt.subplot(324)
#plt.plot(net.nodes[-1].prior.mean_log)
#[plt.axhline(i) for i in beta]
#plt.ylim((-2, 5.))
#plt.subplot(325)
#plt.plot(brier_score_log.T)
#plt.legend(np.arange(nnodes))
#plt.ylim((0, .7))
#plt.subplot(326)
#plt.plot(net.nodes[node_plot].weights_log)
#plt.legend(net.nodes[node_plot].ind_neighbors)
#
##%% nodes
#plt.figure(2)
#for n, node in enumerate(net.nodes):
#    plt.subplot(5, 2, n+1)
#    plt.plot(node.prior.mean_log)
#    [plt.axhline(i) for i in beta]
#    plt.title(n)
