import numpy as np
import matplotlib.pylab as plt
from prettytable import PrettyTable

modes = ['c', 'nocoop']
net_brier = {}
net_preds = {}

directory = 'analyses-10000/'

for mode in modes:
    net_brier[mode] = []
    net_preds[mode] = []
    for f in [directory + mode + '.npz']:
        rec = np.load(f)        
        net_brier[mode].append(rec['net_brier'])
        net_preds[mode] = rec['net_preds'].tolist()
    net_brier[mode] = np.array(net_brier[mode])

#%% Contingency tables
contg = {
'true_pos_rate': {},
'false_neg_rate': {},
'true_neg_rate': {},
'false_pos_rate': {},
'pos_pred_val': {},
'false_disc_rate': {},
'false_omiss_rate': {},
'neg_pred_val': {},
'prevalence': {},
'accuracy': {},
'pos_ll_ratio': {},
'neg_ll_ratio': {},
'dg_odds_ratio': {}
}

for mode in modes:
    v00, v01 = float(net_preds[mode]['00']), float(net_preds[mode]['01'])
    v10, v11 = float(net_preds[mode]['10']), float(net_preds[mode]['11'])
    cond_pos, cond_neg = v00 + v01, v10 + v11
    test_out_pos, test_out_neg = v00 + v10, v01 + v11
    total_popul = v00 + v01 + v10 + v11
    contg['true_pos_rate'][mode] = v00 / cond_pos
    contg['false_neg_rate'][mode] = v01 / cond_pos
    contg['true_neg_rate'][mode] = v11 / cond_neg
    contg['false_pos_rate'][mode] = v10 / cond_neg
    contg['pos_pred_val'][mode] = v00 / test_out_pos
    contg['false_disc_rate'][mode] = v10 / test_out_pos
    contg['false_omiss_rate'][mode] = v01 / test_out_neg
    contg['neg_pred_val'][mode] = v11 / test_out_neg
    contg['prevalence'][mode] = cond_pos / total_popul
    contg['accuracy'][mode] = (v00 + v11) / total_popul
    contg['pos_ll_ratio'][mode] = contg['true_pos_rate'][mode] / contg['false_pos_rate'][mode]
    contg['neg_ll_ratio'][mode] = contg['false_neg_rate'][mode] / contg['true_neg_rate'][mode]
    contg['dg_odds_ratio'][mode] = contg['pos_ll_ratio'][mode] / contg['neg_ll_ratio'][mode]

#%% Printing cont. table
pp = PrettyTable()
pp.add_column('', ['True 0', 'True 1'])
pp.add_column('Pred 0', [str(net_preds['c']['00']) 
                         + ' (' + str(net_preds['nocoop']['00']) + ')',
                         str(net_preds['c']['10'])
                         + ' (' + str(net_preds['nocoop']['10']) + ')',
                         ])
pp.add_column('Pred 1', [str(net_preds['c']['01'])
                         + ' (' + str(net_preds['nocoop']['01']) + ')',
                         str(net_preds['c']['11'])
                         + ' (' + str(net_preds['nocoop']['11']) + ')'
                         ])
print(pp)

#%% Printing cont. table results
pp = PrettyTable(['', 'C', 'NoCoop'])
for k in contg.keys():
    pp.add_row([k, round(contg[k]['c'], 3), round(contg[k]['nocoop'], 3)])
print(pp)

#%% Plotting Brier
markers = ('', '')
lines = ('-', '--')
plt.figure(1, figsize=(8, 4.5))
plt.hold(True)
for m, mode in enumerate(modes):
    plt.plot(net_brier[mode].flatten(),
                      lines[m],
                      marker=markers[m], 
                      color='black',
                      lw=1.6)
plt.legend([m.upper() for m in modes], ncol=len(modes))
plt.ylabel('Brier score')
plt.xlabel('t')
plt.show()
#plt.savefig('figs/net_brier-10000.pdf', bbox_inches='tight')