import numpy as np
import matplotlib.pylab as plt
import networkx as nx

import sys
sys.path.append('/home/jp/diffest/tsp_diffest/python/lib')
from diffest import *
from logreg import *

np.random.seed(12345)

nnodes = 10
ndat = 10000

fn = 'Skin_NonSkin.txt'
data = np.loadtxt(fn)
data[:,-1] -= 1
np.random.shuffle(data)
data = data[:-17]
data = np.c_[np.ones(data.shape[0]), data]   # adding offset term
data = data.reshape(-1, nnodes, data.shape[1])


#%% Data
X = data[:ndat,:,:-1]
y = data[:ndat,:,-1]

#%% Prior
mean = np.zeros(X.shape[-1])
Sigma = np.eye(X.shape[-1]) * 100.
prior = LogReg(mean=mean, Sigma=Sigma)

#%% Network
#G = nx.gnp_random_graph(nnodes, 0.25, seed=12345)
#adjacency_matrix = nx.adjacency_matrix(G).toarray() + np.eye(nnodes)
#adjacency_matrix = np.eye(nnodes)
adjacency_matrix = np.ones((nnodes, nnodes))
G = nx.from_numpy_matrix(adjacency_matrix)
net = Network(adjacency_matrix, prior)

#%% Estimation run
for yst, xst in zip(y, X):
    if net.t % 20 == 0:
        print(net.t, ' ', end='', flush=True)
    net.set_obs(yst, xst)
#    net.exchange_obs()
#    if net.t > 5:
#        net.weights_update()
    net.adapt()
    net.exchange_posteriors()
    net.combine()
    net.log()


#%% Brier
brier_score_log = [node.prior.brier_score_log for node in net.nodes]
brier_score_log = np.array(brier_score_log)
net_brier = brier_score_log.mean(axis=0)
print('Brier: {0:.3f}'.format(brier_score_log[:,-1].mean()))

#%% Contingency
net_preds, _ = net.net_preds()

#%%
fn = 'analyses-central-10000/c.npz'
np.savez(fn, brier_score_log=brier_score_log, 
         net_brier=net_brier, net_preds=net_preds)