from os import listdir
import numpy as np
import matplotlib.pylab as plt

modes = ['atc', 'a', 'c', 'c5', 'nocoop']
forgfact = '096'
netmsd = {}

for mode in modes:
    netmsd[mode] = []
    files = listdir(mode + forgfact)
    files = [f for f in files if f.endswith('.npz')]
    for f in files:
        rec = np.load(mode + forgfact + '/' + f)        
        netmsd[mode].append(rec['netmsd'])
    netmsd[mode] = np.array(netmsd[mode])

#%% Plotting
markers = ('', '', '', 'o', '')
lines = ('-', '-.', '--', 'r--', ':')
plt.figure(1, figsize=(8, 4.5))
plt.hold(True)
for m, mode in enumerate(modes):
    line, = plt.plot(np.log10(netmsd[mode].mean(axis=0)),
                      lines[m],
                      marker=markers[m], 
                      markevery=30,
                      color='black',
                      lw=1.6)
    if m == 1:
        line.set_dashes([10, 2, 2, 2])
plt.legend([m.upper() for m in modes], ncol=5, mode='expand')
plt.ylabel('log MSD')
plt.xlabel('t')
plt.savefig('figs/netmsd' + forgfact + '.pdf', bbox_inches='tight')