import numpy as np
import networkx as nx
import matplotlib.pylab as plt
from copy import deepcopy

import sys
sys.path.append('../lib')
from diffest import *
from poisproc import *

nnodes = 20

amplitude = 2.
offset = 5.
ndat = 500
meas_per_time = nnodes
intensity_arg = np.linspace(0, np.pi, ndat)
intensity = offset + amplitude * np.sin(intensity_arg)
lambd = intensity
forg = .96

y = np.random.poisson(lam=lambd, size=(meas_per_time, ndat)).T


a, b = .1, .1
prior = PoisProc(a, b)
prior.forg = forg

#%% Network
G = nx.gnp_random_graph(nnodes, 0.25, seed=12345)
adjacency_matrix = nx.adjacency_matrix(G).toarray() + np.eye(nnodes)
#adjacency_matrix = np.eye(nnodes)
net_nocoop = Network(adjacency_matrix, prior)
net_atc = deepcopy(net_nocoop)

#%% Estimation run
for yst in y:
    if net_atc.t % 20 == 0:
        print(net_atc.t, ' ', end='', flush=True)
    # ATC
    net_atc.set_obs(yst)
    net_atc.exchange_obs()
#    if net.t > 5:
#        net.weights_update()
    net_atc.adapt()
    net_atc.exchange_posteriors()
    net_atc.combine()
    net_atc.log()

    # NOCOOP
    net_nocoop.set_obs(yst)
    net_nocoop.adapt()
    net_nocoop.log()

#%% Evaluation of results
netmsd_nocoop, nodes_nocoop = net_nocoop.msd_nodes('mean_log', lambd)
netmsd_atc, nodes_atc = net_atc.msd_nodes('mean_log', lambd)
print('\nATC MSD   : ', netmsd_atc[-1])
print('NOCOOP MSD: ', netmsd_nocoop[-1])

node = np.random.randint(0, nnodes)
print('Node: ', node)
print('\nATC MSD  #  : ', nodes_atc[node][-1])
print('NOCOOP MSD #: ', nodes_nocoop[node][-1])

ests_atc = np.array(net_atc.nodes[node].prior.mean_log)
ests_nocoop = np.array(net_nocoop.nodes[node].prior.mean_log)

#%% Figsnocoop
plt.figure(1, figsize=(8, 4.5))
plt.plot(lambd, 'k-', lw=1.5)
plt.hold(True)
line, = plt.plot(ests_atc, 'k--')
line.set_dashes([5, 2])
line, = plt.plot(ests_nocoop, 'k-')
#line.set_dashes([10, 2, 2, 2])
plt.legend([r'$\theta$', 'ATC', 'NOCOOP'], ncol=3, 
           mode='expand', loc='lower center')
plt.ylim((3, 8))
plt.xlabel('t', fontsize='large')
plt.ylabel('Value', fontsize='large')
plt.savefig('figs/theta-evolution.pdf', bbox_inches='tight')