import numpy as np
import networkx as nx

import sys
sys.path.append('../lib')
from diffest import *
from poisproc import *

nnodes = 20

amplitude = 2.
offset = 5.
ndat = 500
meas_per_time = nnodes
intensity_arg = np.linspace(0, np.pi, ndat)
intensity = offset + amplitude * np.sin(intensity_arg)
lambd = intensity
forg = .96

y = np.random.poisson(lam=lambd, size=(meas_per_time, ndat)).T


a, b = .1, .1
prior = PoisProc(a, b)
prior.forg = forg

#%% Network
G = nx.gnp_random_graph(nnodes, 0.25, seed=12345)
adjacency_matrix = nx.adjacency_matrix(G).toarray() + np.eye(nnodes)
#adjacency_matrix = np.eye(nnodes)
net = Network(adjacency_matrix, prior)

#%% Estimation run
for yst in y:
    if net.t % 20 == 0:
        print(net.t, ' ', end='', flush=True)
    net.set_obs(yst)
#    net.exchange_obs()
#    if net.t > 5:
#        net.weights_update()
    net.adapt()
#    net.exchange_posteriors()
#    net.combine()
    net.log()

#%% Evaluation of results
netmsd, nodesmsds = net.msd_nodes('mean_log', lambd)
print('\nNET MSD: ', netmsd[-1])

#%% Saving
fn = 'nocoop096/' + str(np.random.randint(100000, 999999)) + '.npz'
np.savez(fn, netmsd=netmsd, 
         nodesmsds=nodesmsds)